# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi.alert import alert_requests_pb2 as t2iapi_dot_alert_dot_alert__requests__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2


class AlertServiceStub(object):
    """
    Service to handle alert manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetAlertConditionPresence = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlertConditionPresence',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertConditionPresenceRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAlertSignalPresence = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlertSignalPresence',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertSignalPresenceRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAudioPause = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAudioPause',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.CancelAudioPause = channel.unary_unary(
                '/t2iapi.alert.AlertService/CancelAudioPause',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.AlertConditionEscalation = channel.unary_unary(
                '/t2iapi.alert.AlertService/AlertConditionEscalation',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.AlertConditionEscalationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAlarmSignalInactivationState = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlarmSignalInactivationState',
                request_serializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlarmSignalInactivationStateRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetAlertSystemNotFunctional = channel.unary_unary(
                '/t2iapi.alert.AlertService/SetAlertSystemNotFunctional',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.InitiateAlarmOff = channel.unary_unary(
                '/t2iapi.alert.AlertService/InitiateAlarmOff',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )


class AlertServiceServicer(object):
    """
    Service to handle alert manipulations.
    """

    def SetAlertConditionPresence(self, request, context):
        """
        Set the AlertCondition/@Presence of the AlertCondition with the given handle to the given value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAlertSignalPresence(self, request, context):
        """
        Set the AlertSignal/Presence for a given alert signal handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAudioPause(self, request, context):
        """
        Set device audio pause.
        Audio pause: if initiated, all SystemSignalActivation/State for all alarm systems of the device with
        SystemSignalActivation/Manifestation evaluating to 'Aud' shall be set to 'Psd'.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelAudioPause(self, request, context):
        """
        Cancel audio pause.
        Audio pause: suppresses the acoustic alarm signal of the device for all active alarms for a certain period of time.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AlertConditionEscalation(self, request, context):
        """
        Start/Stop an Escalation/Deescalation of the AlertConditionPriority for a given alert condition handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAlarmSignalInactivationState(self, request, context):
        """
        Change the state of the alarm signal inactivation state represented by the AlertCondition with the given
        handle as requested.

        Inactivation States can be for example:
        - Global Audio Pause, could have an condition with the text "Audio Pause"
        - "Pressures Off"
        - Cardiac By-Pass Mode
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAlertSystemNotFunctional(self, request, context):
        """
        Set the AlertSystem with the given handle to not functional.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitiateAlarmOff(self, request, context):
        """
        Initiate alarm off for the AlertCondition with the given handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetAlertConditionPresence': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlertConditionPresence,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertConditionPresenceRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAlertSignalPresence': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlertSignalPresence,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertSignalPresenceRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAudioPause': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAudioPause,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'CancelAudioPause': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelAudioPause,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'AlertConditionEscalation': grpc.unary_unary_rpc_method_handler(
                    servicer.AlertConditionEscalation,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.AlertConditionEscalationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAlarmSignalInactivationState': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlarmSignalInactivationState,
                    request_deserializer=t2iapi_dot_alert_dot_alert__requests__pb2.SetAlarmSignalInactivationStateRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetAlertSystemNotFunctional': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlertSystemNotFunctional,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'InitiateAlarmOff': grpc.unary_unary_rpc_method_handler(
                    servicer.InitiateAlarmOff,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.alert.AlertService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertService(object):
    """
    Service to handle alert manipulations.
    """

    @staticmethod
    def SetAlertConditionPresence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlertConditionPresence',
            t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertConditionPresenceRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAlertSignalPresence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlertSignalPresence',
            t2iapi_dot_alert_dot_alert__requests__pb2.SetAlertSignalPresenceRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAudioPause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAudioPause',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelAudioPause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/CancelAudioPause',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AlertConditionEscalation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/AlertConditionEscalation',
            t2iapi_dot_alert_dot_alert__requests__pb2.AlertConditionEscalationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAlarmSignalInactivationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlarmSignalInactivationState',
            t2iapi_dot_alert_dot_alert__requests__pb2.SetAlarmSignalInactivationStateRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAlertSystemNotFunctional(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/SetAlertSystemNotFunctional',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitiateAlarmOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.alert.AlertService/InitiateAlarmOff',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
