# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/response_types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/response_types.proto\x12\x06t2iapi\x1a\x1egoogle/protobuf/wrappers.proto\"\xac\x01\n\x15PartialIdentification\x12*\n\x04root\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\textension\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x13identification_type\x18\x03 \x01(\x0b\x32\x19.t2iapi.PartialCodedValue\">\n\x11PartialCodedValue\x12)\n\x0ctranslations\x18\x01 \x03(\x0b\x32\x13.t2iapi.Translation\"{\n\x0bTranslation\x12\x18\n\x10translation_code\x18\x01 \x01(\t\x12\x15\n\rcoding_system\x18\x02 \x01(\t\x12;\n\x15\x63oding_system_version\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue*c\n\x06Result\x12\x0f\n\x0bRESULT_FAIL\x10\x00\x12\x12\n\x0eRESULT_SUCCESS\x10\x01\x12\x18\n\x14RESULT_NOT_SUPPORTED\x10\x02\x12\x1a\n\x16RESULT_NOT_IMPLEMENTED\x10\x03\x42+\n\x1a\x63om.draeger.medical.t2iapiB\rResponseTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.response_types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.draeger.medical.t2iapiB\rResponseTypes'
  _RESULT._serialized_start=435
  _RESULT._serialized_end=534
  _PARTIALIDENTIFICATION._serialized_start=72
  _PARTIALIDENTIFICATION._serialized_end=244
  _PARTIALCODEDVALUE._serialized_start=246
  _PARTIALCODEDVALUE._serialized_end=308
  _TRANSLATION._serialized_start=310
  _TRANSLATION._serialized_end=433
# @@protoc_insertion_point(module_scope)
