# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.context import context_requests_pb2 as t2iapi_dot_context_dot_context__requests__pb2
from t2iapi.context import context_responses_pb2 as t2iapi_dot_context_dot_context__responses__pb2


class ContextServiceStub(object):
    """
    Service to handle context manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetLocationDetail = channel.unary_unary(
                '/t2iapi.context.ContextService/SetLocationDetail',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.SetLocationDetailRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.RemoveAllContextStateValidators = channel.unary_unary(
                '/t2iapi.context.ContextService/RemoveAllContextStateValidators',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetContextStateAssociation = channel.unary_unary(
                '/t2iapi.context.ContextService/SetContextStateAssociation',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.SetContextStateAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.CreateContextStateWithAssociation = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssociation',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.CreateContextStateWithAssociationAndValidators = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndValidators',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationAndValidatorsRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.CreateContextStateWithAssociationAndUniqueIdentification = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndUniqueIdentification',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationAndUniqueIdentificationResponse.FromString,
                )
        self.CreateContextStateWithAssocIdentificationAndValidator = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssocIdentificationAndValidator',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.RemoveIdentificationOfContextState = channel.unary_unary(
                '/t2iapi.context.ContextService/RemoveIdentificationOfContextState',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.ChangeIdentificationOfContextState = channel.unary_unary(
                '/t2iapi.context.ContextService/ChangeIdentificationOfContextState',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.CreateContextStateWithAssocAndSpecificValidator = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateContextStateWithAssocAndSpecificValidator',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssocAndSpecificValidatorRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.CreateNeonatalPatientWithAssociationAndMothersIdentification = channel.unary_unary(
                '/t2iapi.context.ContextService/CreateNeonatalPatientWithAssociationAndMothersIdentification',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )
        self.AssociatePatient = channel.unary_unary(
                '/t2iapi.context.ContextService/AssociatePatient',
                request_serializer=t2iapi_dot_context_dot_context__requests__pb2.AssociatePatientRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.EnsembleContextIndicateMembership = channel.unary_unary(
                '/t2iapi.context.ContextService/EnsembleContextIndicateMembership',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.EnsembleContextIndicateMembershipWithIdentification = channel.unary_unary(
                '/t2iapi.context.ContextService/EnsembleContextIndicateMembershipWithIdentification',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.EnsembleContextIndicateMembershipWithIdentificationResponse.FromString,
                )
        self.GetSupportedContextTypes = channel.unary_unary(
                '/t2iapi.context.ContextService/GetSupportedContextTypes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.GetSupportedContextTypesResponse.FromString,
                )
        self.AssociatePatientWithAutoGeneratedPatientId = channel.unary_unary(
                '/t2iapi.context.ContextService/AssociatePatientWithAutoGeneratedPatientId',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
                )


class ContextServiceServicer(object):
    """
    Service to handle context manipulations.
    """

    def SetLocationDetail(self, request, context):
        """
        Use the given LocationDetail in a currently associated LocationContextState or associate a new LocationContextState
        with the LocationDetail.
        The goal of this rpc is to have an associated LocationContextState, that contains the given LocationDetail.
        This can for example be achieved by changing the location of the device in its settings UI.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveAllContextStateValidators(self, request, context):
        """
        Remove all Validators elements for the AbstractContextState with the provided context state handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetContextStateAssociation(self, request, context):
        """
        Set the ContextAssociation of the target ContextState to the given value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssociation(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssociationAndValidators(self, request, context):
        """
        Create a new pm:AbstractContextState instance with the given @ContextAssociation value for the given descriptor handle
        and provide at least the number of pm:Validator elements for this ContextState.
        If the number of pm:Validator elements is zero, zero pm:Validator elements shall be provided.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssociationAndUniqueIdentification(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle
        and provide the unique identification.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssocIdentificationAndValidator(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle
        and provide at least one Identification and Validator for this ContextState.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveIdentificationOfContextState(self, request, context):
        """
        Remove at least one pm:Identification element for the pm:AbstractContextState/@Handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeIdentificationOfContextState(self, request, context):
        """
        Change at least one pm:Identification element for the pm:AbstractContextState/@Handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContextStateWithAssocAndSpecificValidator(self, request, context):
        """
        Create a new ContextState instance with the given ContextAssociation value for the given descriptor handle,
        confirm by requested validator type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNeonatalPatientWithAssociationAndMothersIdentification(self, request, context):
        """
        Create a new neonatal patient with a given type of association and
        including the mothers identification.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssociatePatient(self, request, context):
        """
        Create or adapt a PatientContextState with CoreData/PatientType having the requested patient type.
        The PatientContextState/@ContextAssociation shall be "Associated".
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnsembleContextIndicateMembership(self, request, context):
        """
        Indicate membership in an SDC PARTICIPANT ENSEMBLE using an ensemble context, indicated by its descriptor handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnsembleContextIndicateMembershipWithIdentification(self, request, context):
        """
        Indicate membership in an SDC PARTICIPANT ENSEMBLE using an ensemble context that has the provided descriptor handle
        and return a list of pm:Identification elements which identify an ensemble and thus enable the caller to distinguish
        ensembles from each other.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSupportedContextTypes(self, request, context):
        """
        Returns all types of contexts which are supported by the DUT.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssociatePatientWithAutoGeneratedPatientId(self, request, context):
        """
        Create or adapt a pm:PatientContextState having an associated patient with an auto generated patient id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ContextServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetLocationDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLocationDetail,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.SetLocationDetailRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'RemoveAllContextStateValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveAllContextStateValidators,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetContextStateAssociation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetContextStateAssociation,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.SetContextStateAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'CreateContextStateWithAssociation': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssociation,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'CreateContextStateWithAssociationAndValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssociationAndValidators,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationAndValidatorsRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'CreateContextStateWithAssociationAndUniqueIdentification': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssociationAndUniqueIdentification,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationAndUniqueIdentificationResponse.SerializeToString,
            ),
            'CreateContextStateWithAssocIdentificationAndValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssocIdentificationAndValidator,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'RemoveIdentificationOfContextState': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveIdentificationOfContextState,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'ChangeIdentificationOfContextState': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeIdentificationOfContextState,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'CreateContextStateWithAssocAndSpecificValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContextStateWithAssocAndSpecificValidator,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssocAndSpecificValidatorRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'CreateNeonatalPatientWithAssociationAndMothersIdentification': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNeonatalPatientWithAssociationAndMothersIdentification,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
            'AssociatePatient': grpc.unary_unary_rpc_method_handler(
                    servicer.AssociatePatient,
                    request_deserializer=t2iapi_dot_context_dot_context__requests__pb2.AssociatePatientRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'EnsembleContextIndicateMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.EnsembleContextIndicateMembership,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'EnsembleContextIndicateMembershipWithIdentification': grpc.unary_unary_rpc_method_handler(
                    servicer.EnsembleContextIndicateMembershipWithIdentification,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.EnsembleContextIndicateMembershipWithIdentificationResponse.SerializeToString,
            ),
            'GetSupportedContextTypes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSupportedContextTypes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.GetSupportedContextTypesResponse.SerializeToString,
            ),
            'AssociatePatientWithAutoGeneratedPatientId': grpc.unary_unary_rpc_method_handler(
                    servicer.AssociatePatientWithAutoGeneratedPatientId,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.context.ContextService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ContextService(object):
    """
    Service to handle context manipulations.
    """

    @staticmethod
    def SetLocationDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/SetLocationDetail',
            t2iapi_dot_context_dot_context__requests__pb2.SetLocationDetailRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveAllContextStateValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/RemoveAllContextStateValidators',
            t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetContextStateAssociation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/SetContextStateAssociation',
            t2iapi_dot_context_dot_context__requests__pb2.SetContextStateAssociationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssociation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssociation',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssociationAndValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndValidators',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationAndValidatorsRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssociationAndUniqueIdentification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssociationAndUniqueIdentification',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationAndUniqueIdentificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssocIdentificationAndValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssocIdentificationAndValidator',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveIdentificationOfContextState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/RemoveIdentificationOfContextState',
            t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeIdentificationOfContextState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/ChangeIdentificationOfContextState',
            t2iapi_dot_context_dot_context__requests__pb2.ContextStateHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContextStateWithAssocAndSpecificValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateContextStateWithAssocAndSpecificValidator',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssocAndSpecificValidatorRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNeonatalPatientWithAssociationAndMothersIdentification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/CreateNeonatalPatientWithAssociationAndMothersIdentification',
            t2iapi_dot_context_dot_context__requests__pb2.CreateContextStateWithAssociationRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssociatePatient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/AssociatePatient',
            t2iapi_dot_context_dot_context__requests__pb2.AssociatePatientRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnsembleContextIndicateMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/EnsembleContextIndicateMembership',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnsembleContextIndicateMembershipWithIdentification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/EnsembleContextIndicateMembershipWithIdentification',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.EnsembleContextIndicateMembershipWithIdentificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSupportedContextTypes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/GetSupportedContextTypes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.GetSupportedContextTypesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssociatePatientWithAutoGeneratedPatientId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.context.ContextService/AssociatePatientWithAutoGeneratedPatientId',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            t2iapi_dot_context_dot_context__responses__pb2.CreateContextStateWithAssociationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
