# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/device_responses.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$t2iapi/device/device_responses.proto\x12\rt2iapi.device\x1a\x1ct2iapi/basic_responses.proto\"X\n\x1fGetRemovableDescriptorsResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x0e\n\x06handle\x18\x02 \x03(\t\"T\n\x1bInsertMdsDescriptorResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x0e\n\x06handle\x18\x02 \x01(\tB4\n!com.draeger.medical.t2iapi.deviceB\x0f\x44\x65viceResponsesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.device_responses_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\017DeviceResponses'
  _GETREMOVABLEDESCRIPTORSRESPONSE._serialized_start=85
  _GETREMOVABLEDESCRIPTORSRESPONSE._serialized_end=173
  _INSERTMDSDESCRIPTORRESPONSE._serialized_start=175
  _INSERTMDSDESCRIPTORRESPONSE._serialized_end=259
# @@protoc_insertion_point(module_scope)
