# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/context_responses.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import response_types_pb2 as t2iapi_dot_response__types__pb2
from t2iapi.context import types_pb2 as t2iapi_dot_context_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&t2iapi/context/context_responses.proto\x12\x0et2iapi.context\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/response_types.proto\x1a\x1at2iapi/context/types.proto\"p\n)CreateContextStateWithAssociationResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x1c\n\x14\x63ontext_state_handle\x18\x02 \x01(\t\"\xa8\x01\n@CreateContextStateWithAssociationAndUniqueIdentificationResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x1c\n\x14\x63ontext_state_handle\x18\x02 \x01(\t\x12\x11\n\textension\x18\x03 \x01(\t\x12\x0c\n\x04root\x18\x04 \x01(\t\"|\n GetSupportedContextTypesResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x31\n\x0c\x63ontext_type\x18\x02 \x03(\x0e\x32\x1b.t2iapi.context.ContextType\"\x9b\x01\n;EnsembleContextIndicateMembershipWithIdentificationResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x35\n\x0eidentification\x18\x02 \x03(\x0b\x32\x1d.t2iapi.PartialIdentificationB6\n\"com.draeger.medical.t2iapi.contextB\x10\x43ontextResponsesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.context_responses_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\020ContextResponses'
  _CREATECONTEXTSTATEWITHASSOCIATIONRESPONSE._serialized_start=145
  _CREATECONTEXTSTATEWITHASSOCIATIONRESPONSE._serialized_end=257
  _CREATECONTEXTSTATEWITHASSOCIATIONANDUNIQUEIDENTIFICATIONRESPONSE._serialized_start=260
  _CREATECONTEXTSTATEWITHASSOCIATIONANDUNIQUEIDENTIFICATIONRESPONSE._serialized_end=428
  _GETSUPPORTEDCONTEXTTYPESRESPONSE._serialized_start=430
  _GETSUPPORTEDCONTEXTTYPESRESPONSE._serialized_end=554
  _ENSEMBLECONTEXTINDICATEMEMBERSHIPWITHIDENTIFICATIONRESPONSE._serialized_start=557
  _ENSEMBLECONTEXTINDICATEMEMBERSHIPWITHIDENTIFICATIONRESPONSE._serialized_end=712
# @@protoc_insertion_point(module_scope)
