# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19t2iapi/device/types.proto\x12\rt2iapi.device\x1a\x1egoogle/protobuf/wrappers.proto\"M\n\x0c\x45xpandedName\x12)\n\x03uri\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x12\n\nlocal_name\x18\x02 \x01(\t*\x80\x05\n\nReportType\x12%\n!REPORT_TYPE_EPISODIC_ALERT_REPORT\x10\x00\x12)\n%REPORT_TYPE_EPISODIC_COMPONENT_REPORT\x10\x01\x12\'\n#REPORT_TYPE_EPISODIC_CONTEXT_REPORT\x10\x02\x12&\n\"REPORT_TYPE_EPISODIC_METRIC_REPORT\x10\x03\x12\x31\n-REPORT_TYPE_EPISODIC_OPERATIONAL_STATE_REPORT\x10\x04\x12%\n!REPORT_TYPE_PERIODIC_ALERT_REPORT\x10\x05\x12)\n%REPORT_TYPE_PERIODIC_COMPONENT_REPORT\x10\x06\x12\'\n#REPORT_TYPE_PERIODIC_CONTEXT_REPORT\x10\x07\x12&\n\"REPORT_TYPE_PERIODIC_METRIC_REPORT\x10\x08\x12\x31\n-REPORT_TYPE_PERIODIC_OPERATIONAL_STATE_REPORT\x10\t\x12/\n+REPORT_TYPE_DESCRIPTION_MODIFICATION_REPORT\x10\n\x12(\n$REPORT_TYPE_OPERATION_INVOKED_REPORT\x10\x0b\x12#\n\x1fREPORT_TYPE_SYSTEM_ERROR_REPORT\x10\x0c\x12%\n!REPORT_TYPE_OBSERVED_VALUE_STREAM\x10\r\x12\x1f\n\x1bREPORT_TYPE_WAVEFORM_STREAM\x10\x0e*\x92\x01\n\x10MdsOperatingMode\x12\x1d\n\x19MDS_OPERATING_MODE_NORMAL\x10\x00\x12\x1b\n\x17MDS_OPERATING_MODE_DEMO\x10\x01\x12\x1e\n\x1aMDS_OPERATING_MODE_SERVICE\x10\x02\x12\"\n\x1eMDS_OPERATING_MODE_MAINTENANCE\x10\x03*J\n\x0f\x44\x65scriptorClass\x12\x1d\n\x19\x44\x45SCRIPTOR_CLASS_ABSTRACT\x10\x00\x12\x18\n\x14\x44\x45SCRIPTOR_CLASS_MDS\x10\x01\x42\x30\n!com.draeger.medical.t2iapi.deviceB\x0b\x44\x65viceTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\013DeviceTypes'
  _REPORTTYPE._serialized_start=156
  _REPORTTYPE._serialized_end=796
  _MDSOPERATINGMODE._serialized_start=799
  _MDSOPERATINGMODE._serialized_end=945
  _DESCRIPTORCLASS._serialized_start=947
  _DESCRIPTORCLASS._serialized_end=1021
  _EXPANDEDNAME._serialized_start=76
  _EXPANDEDNAME._serialized_end=153
# @@protoc_insertion_point(module_scope)
