# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1at2iapi/context/types.proto\x12\x0et2iapi.context\x1a\x1egoogle/protobuf/wrappers.proto\"\x9f\x02\n\x0eLocationDetail\x12)\n\x03poc\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04room\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03\x62\x65\x64\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x66\x61\x63ility\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x62uilding\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x66loor\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue*\xaf\x01\n\x12\x43ontextAssociation\x12&\n\"CONTEXT_ASSOCIATION_NOT_ASSOCIATED\x10\x00\x12&\n\"CONTEXT_ASSOCIATION_PRE_ASSOCIATED\x10\x01\x12\"\n\x1e\x43ONTEXT_ASSOCIATION_ASSOCIATED\x10\x02\x12%\n!CONTEXT_ASSOCIATION_DISASSOCIATED\x10\x03*\xc8\x01\n\x0bPatientType\x12\x1c\n\x18PATIENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12PATIENT_TYPE_ADULT\x10\x01\x12\x1b\n\x17PATIENT_TYPE_ADOLESCENT\x10\x02\x12\x1a\n\x16PATIENT_TYPE_PEDIATRIC\x10\x03\x12\x17\n\x13PATIENT_TYPE_INFANT\x10\x04\x12\x19\n\x15PATIENT_TYPE_NEONATAL\x10\x05\x12\x16\n\x12PATIENT_TYPE_OTHER\x10\x06*\xe2\x01\n\rValidatorType\x12\x17\n\x13VALIDATOR_TYPE_USER\x10\x00\x12&\n\"VALIDATOR_TYPE_CLINICAL_SUPER_USER\x10\x01\x12\x19\n\x15VALIDATOR_TYPE_BIOMED\x10\x02\x12$\n VALIDATOR_TYPE_SERVICE_PERSONNEL\x10\x03\x12+\n\'VALIDATOR_TYPE_REMOTE_SERVICE_OPERATION\x10\x04\x12\"\n\x1eVALIDATOR_TYPE_TECHNICAL_MEANS\x10\x05*\xab\x01\n\x0b\x43ontextType\x12\x18\n\x14\x43ONTEXT_TYPE_PATIENT\x10\x00\x12\x19\n\x15\x43ONTEXT_TYPE_LOCATION\x10\x01\x12\x19\n\x15\x43ONTEXT_TYPE_WORKFLOW\x10\x02\x12\x19\n\x15\x43ONTEXT_TYPE_OPERATOR\x10\x03\x12\x16\n\x12\x43ONTEXT_TYPE_MEANS\x10\x04\x12\x19\n\x15\x43ONTEXT_TYPE_ENSEMBLE\x10\x05\x42\x32\n\"com.draeger.medical.t2iapi.contextB\x0c\x43ontextTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\014ContextTypes'
  _CONTEXTASSOCIATION._serialized_start=369
  _CONTEXTASSOCIATION._serialized_end=544
  _PATIENTTYPE._serialized_start=547
  _PATIENTTYPE._serialized_end=747
  _VALIDATORTYPE._serialized_start=750
  _VALIDATORTYPE._serialized_end=976
  _CONTEXTTYPE._serialized_start=979
  _CONTEXTTYPE._serialized_end=1150
  _LOCATIONDETAIL._serialized_start=79
  _LOCATIONDETAIL._serialized_end=366
# @@protoc_insertion_point(module_scope)
