# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19t2iapi/metric/types.proto\x12\rt2iapi.metric*\xe7\x02\n\x13MeasurementValidity\x12\x1e\n\x1aMEASUREMENT_VALIDITY_VALID\x10\x00\x12\'\n#MEASUREMENT_VALIDITY_VALIDATED_DATA\x10\x01\x12,\n(MEASUREMENT_VALIDITY_MEASUREMENT_ONGOING\x10\x02\x12%\n!MEASUREMENT_VALIDITY_QUESTIONABLE\x10\x03\x12,\n(MEASUREMENT_VALIDITY_CALIBRATION_ONGOING\x10\x04\x12 \n\x1cMEASUREMENT_VALIDITY_INVALID\x10\x05\x12!\n\x1dMEASUREMENT_VALIDITY_OVERFLOW\x10\x06\x12\"\n\x1eMEASUREMENT_VALIDITY_UNDERFLOW\x10\x07\x12\x1b\n\x17MEASUREMENT_VALIDITY_NA\x10\x08*^\n\x0eGenerationMode\x12\x18\n\x14GENERATION_MODE_REAL\x10\x00\x12\x18\n\x14GENERATION_MODE_TEST\x10\x01\x12\x18\n\x14GENERATION_MODE_DEMO\x10\x02*t\n\x13OperationModeStatus\x12\x1c\n\x18OPERATION_MODE_STATUS_ON\x10\x00\x12\x1d\n\x19OPERATION_MODE_STATUS_OFF\x10\x01\x12 \n\x1cOPERATION_MODE_STATUS_PAUSED\x10\x02*\xa6\x02\n\x0cMetricStatus\x12&\n\"METRIC_STATUS_PERFORMED_OR_APPLIED\x10\x00\x12(\n$METRIC_STATUS_CURRENTLY_INITIALIZING\x10\x01\x12<\n8METRIC_STATUS_INITIALIZED_BUT_NOT_PERFORMING_OR_APPLYING\x10\x02\x12+\n\'METRIC_STATUS_CURRENTLY_DE_INITIALIZING\x10\x03\x12?\n;METRIC_STATUS_DE_INITIALIZED_AND_NOT_PERFORMING_OR_APPLYING\x10\x04\x12\x18\n\x14METRIC_STATUS_FAILED\x10\x05\x42\x30\n!com.draeger.medical.t2iapi.metricB\x0bMetricTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.metric.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\013MetricTypes'
  _MEASUREMENTVALIDITY._serialized_start=45
  _MEASUREMENTVALIDITY._serialized_end=404
  _GENERATIONMODE._serialized_start=406
  _GENERATIONMODE._serialized_end=500
  _OPERATIONMODESTATUS._serialized_start=502
  _OPERATIONMODESTATUS._serialized_end=618
  _METRICSTATUS._serialized_start=621
  _METRICSTATUS._serialized_end=915
# @@protoc_insertion_point(module_scope)
