# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/activation_state/activation_state_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.activation_state import types_pb2 as t2iapi_dot_activation__state_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7t2iapi/activation_state/activation_state_requests.proto\x12\x17t2iapi.activation_state\x1a#t2iapi/activation_state/types.proto\"q\n\x1dSetComponentActivationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12@\n\nactivation\x18\x02 \x01(\x0e\x32,.t2iapi.activation_state.ComponentActivation\"i\n\x19SetAlertActivationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12<\n\nactivation\x18\x02 \x01(\x0e\x32(.t2iapi.activation_state.AlertActivation\"\xba\x01\n SetSystemSignalActivationRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12H\n\rmanifestation\x18\x02 \x01(\x0e\x32\x31.t2iapi.activation_state.AlertSignalManifestation\x12<\n\nactivation\x18\x03 \x01(\x0e\x32(.t2iapi.activation_state.AlertActivationBF\n+com.draeger.medical.t2iapi.activation_stateB\x17\x41\x63tivationStateRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.activation_state.activation_state_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.draeger.medical.t2iapi.activation_stateB\027ActivationStateRequests'
  _SETCOMPONENTACTIVATIONREQUEST._serialized_start=121
  _SETCOMPONENTACTIVATIONREQUEST._serialized_end=234
  _SETALERTACTIVATIONREQUEST._serialized_start=236
  _SETALERTACTIVATIONREQUEST._serialized_end=341
  _SETSYSTEMSIGNALACTIVATIONREQUEST._serialized_start=344
  _SETSYSTEMSIGNALACTIVATIONREQUEST._serialized_end=530
# @@protoc_insertion_point(module_scope)
