# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi.device import device_requests_pb2 as t2iapi_dot_device_dot_device__requests__pb2
from t2iapi.device import device_responses_pb2 as t2iapi_dot_device_dot_device__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/device/service.proto\x12\rt2iapi.device\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/basic_requests.proto\x1a#t2iapi/device/device_requests.proto\x1a$t2iapi/device/device_responses.proto2\xe6\x08\n\rDeviceService\x12]\n\x16SetDeviceOperatingMode\x12,.t2iapi.device.SetDeviceOperatingModeRequest\x1a\x15.t2iapi.BasicResponse\x12?\n\x0eShutDownDevice\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12=\n\x0c\x42ootUpDevice\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12:\n\tSendHello\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12?\n\x0eSetClockDevice\x12\x16.google.protobuf.Empty\x1a\x15.t2iapi.BasicResponse\x12G\n\x0bSetLanguage\x12!.t2iapi.device.SetLanguageRequest\x1a\x15.t2iapi.BasicResponse\x12\x86\x01\n\x1eGetRemovableDescriptorsOfClass\x12\x34.t2iapi.device.GetRemovableDescriptorsOfClassRequest\x1a..t2iapi.device.GetRemovableDescriptorsResponse\x12\x45\n\x10RemoveDescriptor\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x45\n\x10InsertDescriptor\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12Y\n\x14\x43hangeMdibSequenceID\x12*.t2iapi.device.ChangeMdibSequenceIdRequest\x1a\x15.t2iapi.BasicResponse\x12Y\n\x13InsertMdsDescriptor\x12\x16.google.protobuf.Empty\x1a*.t2iapi.device.InsertMdsDescriptorResponse\x12H\n\x13RemoveMdsDescriptor\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12L\n\x17TriggerDescriptorUpdate\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12K\n\rTriggerReport\x12#.t2iapi.device.TriggerReportRequest\x1a\x15.t2iapi.BasicResponseB5\n!com.draeger.medical.t2iapi.deviceB\x10\x44\x65viceApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\020DeviceApiService'
  _DEVICESERVICE._serialized_start=210
  _DEVICESERVICE._serialized_end=1336
# @@protoc_insertion_point(module_scope)
